@@ -1,8 +1,9 @@
 package Net::Gadu;
 
 use 5.006;
-use strict;
 use warnings;
+use Socket;
+use strict;
 
 require Exporter;
 require DynaLoader;
@@ -16,7 +17,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 	
 );
-our $VERSION = '0.5.3';
+our $VERSION = '0.10';
 our $EVENT_NONE = 0;
 our $EVENT_MSG = 1;
 our $EVENT_NOTIFY = 2;
@@ -34,7 +35,7 @@ bootstrap Net::Gadu $VERSION;
 sub new {
     my ($c, %args) = @_;
     my $class = ref($c) || $c;
-    if (!exists($args{server})) { $args{server} = "217.17.41.84"; }
+    if (!exists($args{server})) { $args{server} = "217.17.41.88"; }
     if (!exists($args{async})) { $args{async} = 0; }
     bless \%args, $class;
 }
@@ -50,6 +51,11 @@ sub search {
     return Net::Gadu::gg_search($nickname,$first_name,$last_name,$city,$gd{$gender},$active);
 }
 
+sub search_uin {
+    my ($cl,$uin,$active) = @_;
+    return Net::Gadu::gg_search_uin($uin,$active);
+}
+
 sub login {
     my ($cl,$uin,$password) = @_;
     $cl->{uin}=$uin;
@@ -134,7 +140,7 @@ biblioteka ta jest automatycznie instalowana w systemie.
 
 =head1 DOWNLOAD
 
-http://krzak.linux.net.pl/perl/Net-Gadu-0.5.3.tar.gz
+http://krzak.linux.net.pl/perl/Net-Gadu-0.9.tar.gz
 
 =head1 METHODS
 
@@ -144,38 +150,53 @@ Dostepne metody :
 
 =item $gg = new Net::Gadu(server => "server_ip")
 
-    opcjonalny parametr : server   (ip alternatywnego serwera)
-			  async = 1 lub 0   (komunikacja asynchroniczna)
+    opcjonalny parametr :
+    server => "11.11.11.11"  (ip alternatywnego serwera)
+    async => 1 lub 0   (komunikacja asynchroniczna)
+
 
 =item $gg->login(uin, password);
 
 Polaczenie z serwerem i zalogowanie.
 
+
 =item $gg->logoff();
 
 Zakonczenie sesji.
 
+
 =item $gg->send_message(receiver_uin, message);
 
 Wysyla wiadomosc pod podany UIN.
 
+
 =item $gg->send_message_chat(receiver_uin, message);
 
 Wysyla wiadomosc pod podany UIN.
 
+
 =item $gg->set_available();
 
 Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_not_available().
 
+
 =item $gg->search($nickname,$first_name,$last_name,$city,$gender,$active)
 
     $gender = "male" lub "female" lub "none")
     $active = 1 lub 0
 
+
+=item $gg->search_uin($uin,$active)
+    
+    szuka uzytkownika o podanym UIN 
+    (active oznacza czy ma szukac posrod aktywnych czy nie)
+
+
 =item $gg->check_event()
 
     Sprawdza czy zaszlo jakies zdarzenie (przydatne przy polaczeniu asynchronicznym zwlaszcza)
     
+
 =item $gg->get_event()
 
     Zwraca dane ze zdarzenia ktore zaszlo, zwracany jest hasz np :
@@ -200,16 +221,16 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
 
     Dostepne kody zdarzen :
     
-    $Net::Gadu::EVENT_NONE = 0
-    $Net::Gadu::EVENT_MSG = 1
-    $Net::Gadu::EVENT_NOTIFY = 2
-    $Net::Gadu::EVENT_NOTIFY_DESCR = 3
-    $Net::Gadu::EVENT_STATUS = 4
-    $Net::Gadu::EVENT_ACK = 5
-    $Net::Gadu::EVENT_PONG = 6
-    $Net::Gadu::EVENT_CONN_FAILED = 7
-    $Net::Gadu::EVENT_CONN_SUCCESS = 8
-    $Net::Gadu::EVENT_DISCONNECT = 9
+    $Net::Gadu::EVENT_NONE
+    $Net::Gadu::EVENT_MSG
+    $Net::Gadu::EVENT_NOTIFY
+    $Net::Gadu::EVENT_NOTIFY_DESCR
+    $Net::Gadu::EVENT_STATUS
+    $Net::Gadu::EVENT_ACK
+    $Net::Gadu::EVENT_PONG
+    $Net::Gadu::EVENT_CONN_FAILED
+    $Net::Gadu::EVENT_CONN_SUCCESS 
+    $Net::Gadu::EVENT_DISCONNECT
 
 
 =back
@@ -220,7 +241,6 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
 
     #!/usr/bin/perl
 
-    use ExtUtils::testlib;
     use Net::Gadu;
 
     my $gg = new Net::Gadu(async=>1);
@@ -228,7 +248,7 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
     # SEARCH
     my $res = $gg->search("","Ania","","","female",0);
     foreach my $a (@{$res}) {
-        print $a->{nickname}." ".$a->{uin}." ".$a->{first_name}." ".$a->{last_name}." ".$a->{city}." ".$a->{born}."\n";
+        print $a->{nickname}." ".$a->{uin}." ".$a->{first_name}." ".$a->{last_name}." ".$a->{city}." ".$a->{born}." ".$a->{active}."\n";
     }
 
     #print ($res->[1]->{uin});
@@ -238,16 +258,21 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
     ## LOGIN
     $gg->login("12121212","password") or die "Login error\n";
 
-    ## EVENTS(this example, after successful login change status, send message and logout
-    while ($gg->check_event() == 1) {
+    ## EVENTS this example, after successful login change status, send message and logout
+    while (1) {
+      while ($gg->check_event() == 1) {
 
 	my $e = $gg->get_event();
 
 	my $type = $e->{type};
+
+	if ($type == $Net::Gadu::EVENT_CONN_FAILED) {
+	    die "Connection failed";
+	}
 	
 	if ($type == $Net::Gadu::EVENT_CONN_SUCCESS) {
 	    $gg->set_available();
-	    $gg->send_message_chat("42112","dziekuje za Net::Gadu :))");
+	    $gg->send_message_chat("42112","dziekuje za Net::Gadu");
 	}
 
 	if ($type == $Net::Gadu::EVENT_MSG) {
@@ -258,7 +283,8 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
 	if ($type == $Net::Gadu::EVENT_ACK) {
 	    $gg->logoff();
 	}
-	
+
+      }
     }
 
 =back
